/* Time-stamp: <2005-01-21 22:30:22 poser> */

/*
 * Copyright (C) 1993-2002 William J. Poser (billposer@alum.mit.edu).
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdio.h>
#include "limits.h"
#include "defs.h"

static char rcsid[] = "$Id: info.c,v 1.11 2004/08/08 06:31:32 poser Exp poser $";

void
PrintFlags(FILE *fp)
{
   fprintf(fp,"Flags:");
   fprintf(fp,"\t-h                   Print usage message\n");
   fprintf(fp,"\t-v                   Print version message\n");
   fprintf(fp,"\t-D                   List defaults\n");
   fprintf(fp,"\t-F                   List command line flags\n");
   fprintf(fp,"\t-L                   List limits\n");
   fputc('\n',fp);
   
   fprintf(fp,"\t-b                   A record is terminated by two or more newlines\n");
   fprintf(fp,"\t-l                   A record consists of a single line\n");
   fprintf(fp,"\t-r <separator>       A record is terminated by separator character\n");
	
   fputc('\n',fp);
   fprintf(fp,"\t-d <character>+      Fields are delimited by the named character(s)\n");
   fprintf(fp,"\t-w                   Sort on the entire text of the record\n");
   fputc('\n',fp);	
   fprintf(fp,"\t-M <records>         Set initial maximum number of records \n");
   fprintf(fp,"\t-f <date format>     Permutation of ymd with separators\n");
   fprintf(fp,"\t-I                   Invert sense of comparisons globally\n");
   fprintf(fp,"\t-q                   Be quiet - do not chat while working\n");
   fprintf(fp,"Key specific flags:\n");
   fprintf(fp,"\t-n <field number>    Sort on the specified field (counting from one;\n\t\t\t\tnegative means from right)\n");
   fprintf(fp,"\t-t <tag regexp>      Sort on the field with the specified tag\n");
   fprintf(fp,"\t-o <comparison>      Optional: compare as (<,=,>) to present key if absent\n");
   fprintf(fp,"\t-c <key type>        l(exicographic), t(ime), d(ate), n(umeric), s(ize)\n");
   fprintf(fp,"\t-s <file name>       Read sort order from named file\n");
   fprintf(fp,"\t-x <file name>       Read exclusions from named file\n");
   fprintf(fp,"\t-X <exclusions>      Exclude specified characters\n");
   fprintf(fp,"\t-i                   Invert sense of comparisons\n");
   fprintf(fp,"\t-R                   Reverse characters of key\n");
   fputc('\n',fp);				
	
}

void
PrintDefaults(FILE *fp)
{

   fprintf(fp,"Defaults:\n");
   fprintf(fp,"    Field terminator character(s)\n");
   fprintf(fp,"        Record = line               whitespace (space or tab)\n");
   fprintf(fp,"        Record = block              newline\n");
   fprintf(fp,"    Key specification               whole record\n");
   fprintf(fp,"    Initial number of records       %4d\n",DEFMAXRECORDS);
   fprintf(fp,"    Presence of key                 obligatory\n");
   fprintf(fp,"    Record type                     double newline terminated block\n");
   fprintf(fp,"    Sense of sort                   forward\n");	
   fprintf(fp,"    Date format                     year/month/day\n");
   fprintf(fp,"    Sort order                      machine collating (usually ASCII)\n");	
   fprintf(fp,"    Sort type                       lexicographic\n");
   fprintf(fp,"\n");
}

void
PrintLimits(FILE *fp)
{

   fprintf(fp,"Limits:\n");
   fprintf(fp,"   Maximum number of keys             %2d\n",MAXKEYS);
   fprintf(fp,"   Number of multigraphs per key   %5d\n",MAXMULTIGRAPHS);
   fprintf(fp,"\n");
}


void
PrintUsage(void)
{
   extern char progname[];
	
   fprintf(stdout,"\n");
	fprintf(stdout,
		"This program sorts text using arbitrary sort orders\n");
   fprintf(stdout,
		"on fields specified on the command-line. If no input\n");
   fprintf(stdout,
		"file is specified, input is read from the standard input.\n");
   fprintf(stdout,"Usage: %s <flags> (<input file name>)\n",progname);
   fprintf(stdout,"Type %s -F to obtain a list of flags.\n\n",progname);
}
